class LivemarkException(Exception):
    """Livemark exception

    API      | Usage
    -------- | --------
    Public   | `from livemark import LivemarkException`

    """

    pass
